@@ -15,24 +15,22 @@ QwtSymbol
 
 import math
 
-from qwt.graphic import QwtGraphic
-from qwt.painter import QwtPainter
-
+from qtpy.QtCore import QLineF, QPoint, QPointF, QRect, QRectF, QSize, QSizeF, Qt
 from qtpy.QtGui import (
-    QPainter,
-    QTransform,
-    QPixmap,
-    QPen,
-    QPolygonF,
-    QPainterPath,
     QBrush,
+    QPainter,
+    QPainterPath,
+    QPen,
+    QPixmap,
+    QPolygonF,
+    QTransform,
 )
-from qtpy.QtCore import QSize, QRect, QPointF, QRectF, QSizeF, Qt, QPoint, QLineF
 from qtpy.QtSvg import QSvgRenderer
 
+from qwt.graphic import QwtGraphic
+
 
 class QwtTriangle(object):
-
     # enum Type
     Left, Right, Up, Down = list(range(4))
 
@@ -62,7 +60,7 @@ def qwtScaleBoundingRect(graphic, size):
     return graphic.scaledBoundingRect(sx, sy)
 
 
-def qwtDrawPixmapSymbols(painter, points, numPoints, symbol):
+def qwtDrawPixmapSymbols(painter, points, symbol):
     size = symbol.size()
     if size.isEmpty():
         size = symbol.pixmap().size()
@@ -79,10 +77,10 @@ def qwtDrawPixmapSymbols(painter, points, numPoints, symbol):
     painter.resetTransform()
     for pos in points:
         pos = QPointF(transform.map(pos)) - pinPoint
-        QwtPainter.drawPixmap(painter, QRect(pos.toPoint(), pm.size()), pm)
+        painter.drawPixmap(QRect(pos.toPoint(), pm.size()), pm)
 
 
-def qwtDrawSvgSymbols(painter, points, numPoints, renderer, symbol):
+def qwtDrawSvgSymbols(painter, points, renderer, symbol):
     if renderer is None or not renderer.isValid():
         return
     viewBox = QRectF(renderer.viewBoxF())
@@ -104,7 +102,7 @@ def qwtDrawSvgSymbols(painter, points, numPoints, renderer, symbol):
         renderer.render(painter, QRectF(x, y, sz.width(), sz.height()))
 
 
-def qwtDrawGraphicSymbols(painter, points, numPoint, graphic, symbol):
+def qwtDrawGraphicSymbols(painter, points, graphic, symbol):
     pointRect = QRectF(graphic.controlPointRect())
     if pointRect.isEmpty():
         return
@@ -128,7 +126,7 @@ def qwtDrawGraphicSymbols(painter, points, numPoint, graphic, symbol):
     painter.setTransform(transform)
 
 
-def qwtDrawEllipseSymbols(painter, points, numPoints, symbol):
+def qwtDrawEllipseSymbols(painter, points, symbol):
     painter.setBrush(symbol.brush())
     painter.setPen(symbol.pen())
     size = symbol.size()
@@ -143,7 +141,7 @@ def qwtDrawEllipseSymbols(painter, points, numPoints, symbol):
         painter.drawEllipse(r)
 
 
-def qwtDrawRectSymbols(painter, points, numPoints, symbol):
+def qwtDrawRectSymbols(painter, points, symbol):
     size = symbol.size()
     pen = QPen(symbol.pen())
     pen.setJoinStyle(Qt.MiterJoin)
@@ -161,7 +159,7 @@ def qwtDrawRectSymbols(painter, points, numPoints, symbol):
         painter.drawRect(r)
 
 
-def qwtDrawDiamondSymbols(painter, points, numPoints, symbol):
+def qwtDrawDiamondSymbols(painter, points, symbol):
     size = symbol.size()
     pen = QPen(symbol.pen())
     pen.setJoinStyle(Qt.MiterJoin)
@@ -180,7 +178,7 @@ def qwtDrawDiamondSymbols(painter, points, numPoints, symbol):
         painter.drawPolygon(polygon)
 
 
-def qwtDrawTriangleSymbols(painter, type, points, numPoint, symbol):
+def qwtDrawTriangleSymbols(painter, type, points, symbol):
     size = symbol.size()
     pen = QPen(symbol.pen())
     pen.setJoinStyle(Qt.MiterJoin)
@@ -208,7 +206,7 @@ def qwtDrawTriangleSymbols(painter, type, points, numPoint, symbol):
         painter.drawPolygon(QPolygonF(triangle))
 
 
-def qwtDrawLineSymbols(painter, orientations, points, numPoints, symbol):
+def qwtDrawLineSymbols(painter, orientations, points, symbol):
     size = symbol.size()
     pen = QPen(symbol.pen())
     if pen.width() > 1:
@@ -230,7 +228,7 @@ def qwtDrawLineSymbols(painter, orientations, points, numPoints, symbol):
             painter.drawLine(QLineF(x, y, x, y + sh))
 
 
-def qwtDrawXCrossSymbols(painter, points, numPoints, symbol):
+def qwtDrawXCrossSymbols(painter, points, symbol):
     size = symbol.size()
     pen = QPen(symbol.pen())
     if pen.width() > 1:
@@ -249,13 +247,13 @@ def qwtDrawXCrossSymbols(painter, points, numPoints, symbol):
         painter.drawLine(QLineF(x2, y1, x1, y2))
 
 
-def qwtDrawStar1Symbols(painter, points, numPoints, symbol):
+def qwtDrawStar1Symbols(painter, points, symbol):
     size = symbol.size()
     painter.setPen(symbol.pen())
     sqrt1_2 = math.sqrt(0.5)
     r = QRectF(0, 0, size.width(), size.height())
     for pos in points:
-        r.moveCenter(pos.toPoint())
+        r.moveCenter(pos)
         c = QPointF(r.center())
         d1 = r.width() / 2.0 * (1.0 - sqrt1_2)
         painter.drawLine(
@@ -268,7 +266,7 @@ def qwtDrawStar1Symbols(painter, points, numPoints, symbol):
         painter.drawLine(QLineF(r.left(), c.y(), r.right(), c.y()))
 
 
-def qwtDrawStar2Symbols(painter, points, numPoints, symbol):
+def qwtDrawStar2Symbols(painter, points, symbol):
     pen = QPen(symbol.pen())
     if pen.width() > 1:
         pen.setCapStyle(Qt.FlatCap)
@@ -310,7 +308,7 @@ def qwtDrawStar2Symbols(painter, points, numPoints, symbol):
         painter.drawPolygon(QPolygonF(star))
 
 
-def qwtDrawHexagonSymbols(painter, points, numPoints, symbol):
+def qwtDrawHexagonSymbols(painter, points, symbol):
     painter.setBrush(symbol.brush())
     painter.setPen(symbol.pen())
     cos30 = math.cos(30 * math.pi / 180.0)
@@ -353,11 +351,7 @@ class QwtSymbol_PrivateData(object):
 
         self.path = Path()
 
-        class Pixmap(object):
-            def __init__(self):
-                self.pixmap = QPixmap()
-
-        self.pixmap = None  # Pixmap()
+        self.pixmap = None
 
         class Graphic(object):
             def __init__(self):
@@ -693,7 +687,7 @@ class QwtSymbol(object):
 
             app.exec_()
 
-        .. image:: /images/symbol_path_example.png
+        .. image:: /_static/symbol_path_example.png
 
         :param QPainterPath path: Painter path
 
@@ -734,7 +728,7 @@ class QwtSymbol(object):
             `brush()` and `pen()` have no effect
         """
         self.__data.style = QwtSymbol.Pixmap
-        self.__data.pixmap.pixmap = pixmap
+        self.__data.pixmap = pixmap
 
     def pixmap(self):
         """
@@ -744,7 +738,9 @@ class QwtSymbol(object):
 
             :py:meth:`setPixmap()`
         """
-        return self.__data.pixmap.pixmap
+        if self.__data.pixmap is None:
+            return QPixmap()
+        return self.__data.pixmap
 
     def setGraphic(self, graphic):
         """
@@ -1033,7 +1029,7 @@ class QwtSymbol(object):
         """
         return self.__data.isPinPointEnabled
 
-    def drawSymbols(self, painter, points, numPoints=None):
+    def drawSymbols(self, painter, points):
         """
         Render an array of symbols
 
@@ -1044,11 +1040,8 @@ class QwtSymbol(object):
         :param QPainter painter: Painter
         :param QPolygonF points: Positions of the symbols in screen coordinates
         """
-        # TODO: remove argument numPoints (not necessary in `PythonQwt`)
-        if numPoints is not None and numPoints <= 0:
-            return
         painter.save()
-        self.renderSymbols(painter, points, numPoints)
+        self.renderSymbols(painter, points)
         painter.restore()
 
     def drawSymbol(self, painter, point_or_rect):
@@ -1106,68 +1099,53 @@ class QwtSymbol(object):
             self.__data.isPinPointEnabled = isPinPointEnabled
             painter.restore()
 
-    def renderSymbols(self, painter, points, numPoints=None):
+    def renderSymbols(self, painter, points):
         """
         Render the symbol to series of points
 
         :param QPainter painter: Painter
         :param point_or_rect: Positions of the symbols
         """
-        # TODO: remove argument numPoints (not necessary in `PythonQwt`)
-        try:
-            assert numPoints is None
-        except AssertionError:
-            raise RuntimeError(
-                "argument numPoints is not implemented " "in `PythonQwt`"
-            )
         if self.__data.style == QwtSymbol.Ellipse:
-            qwtDrawEllipseSymbols(painter, points, numPoints, self)
+            qwtDrawEllipseSymbols(painter, points, self)
         elif self.__data.style == QwtSymbol.Rect:
-            qwtDrawRectSymbols(painter, points, numPoints, self)
+            qwtDrawRectSymbols(painter, points, self)
         elif self.__data.style == QwtSymbol.Diamond:
-            qwtDrawDiamondSymbols(painter, points, numPoints, self)
+            qwtDrawDiamondSymbols(painter, points, self)
         elif self.__data.style == QwtSymbol.Cross:
-            qwtDrawLineSymbols(
-                painter, Qt.Horizontal | Qt.Vertical, points, numPoints, self
-            )
+            qwtDrawLineSymbols(painter, Qt.Horizontal | Qt.Vertical, points, self)
         elif self.__data.style == QwtSymbol.XCross:
-            qwtDrawXCrossSymbols(painter, points, numPoints, self)
+            qwtDrawXCrossSymbols(painter, points, self)
         elif self.__data.style in (QwtSymbol.Triangle, QwtSymbol.UTriangle):
-            qwtDrawTriangleSymbols(painter, QwtTriangle.Up, points, numPoints, self)
+            qwtDrawTriangleSymbols(painter, QwtTriangle.Up, points, self)
         elif self.__data.style == QwtSymbol.DTriangle:
-            qwtDrawTriangleSymbols(painter, QwtTriangle.Down, points, numPoints, self)
+            qwtDrawTriangleSymbols(painter, QwtTriangle.Down, points, self)
         elif self.__data.style == QwtSymbol.RTriangle:
-            qwtDrawTriangleSymbols(painter, QwtTriangle.Right, points, numPoints, self)
+            qwtDrawTriangleSymbols(painter, QwtTriangle.Right, points, self)
         elif self.__data.style == QwtSymbol.LTriangle:
-            qwtDrawTriangleSymbols(painter, QwtTriangle.Left, points, numPoints, self)
+            qwtDrawTriangleSymbols(painter, QwtTriangle.Left, points, self)
         elif self.__data.style == QwtSymbol.HLine:
-            qwtDrawLineSymbols(painter, Qt.Horizontal, points, numPoints, self)
+            qwtDrawLineSymbols(painter, Qt.Horizontal, points, self)
         elif self.__data.style == QwtSymbol.VLine:
-            qwtDrawLineSymbols(painter, Qt.Vertical, points, numPoints, self)
+            qwtDrawLineSymbols(painter, Qt.Vertical, points, self)
         elif self.__data.style == QwtSymbol.Star1:
-            qwtDrawStar1Symbols(painter, points, numPoints, self)
+            qwtDrawStar1Symbols(painter, points, self)
         elif self.__data.style == QwtSymbol.Star2:
-            qwtDrawStar2Symbols(painter, points, numPoints, self)
+            qwtDrawStar2Symbols(painter, points, self)
         elif self.__data.style == QwtSymbol.Hexagon:
-            qwtDrawHexagonSymbols(painter, points, numPoints, self)
+            qwtDrawHexagonSymbols(painter, points, self)
         elif self.__data.style == QwtSymbol.Path:
             if self.__data.path.graphic.isNull():
                 self.__data.path.graphic = qwtPathGraphic(
                     self.__data.path.path, self.__data.pen, self.__data.brush
                 )
-            qwtDrawGraphicSymbols(
-                painter, points, numPoints, self.__data.path.graphic, self
-            )
+            qwtDrawGraphicSymbols(painter, points, self.__data.path.graphic, self)
         elif self.__data.style == QwtSymbol.Pixmap:
-            qwtDrawPixmapSymbols(painter, points, numPoints, self)
+            qwtDrawPixmapSymbols(painter, points, self)
         elif self.__data.style == QwtSymbol.Graphic:
-            qwtDrawGraphicSymbols(
-                painter, points, numPoints, self.__data.graphic.graphic, self
-            )
+            qwtDrawGraphicSymbols(painter, points, self.__data.graphic.graphic, self)
         elif self.__data.style == QwtSymbol.SvgDocument:
-            qwtDrawSvgSymbols(
-                painter, points, numPoints, self.__data.svg.renderer, self
-            )
+            qwtDrawSvgSymbols(painter, points, self.__data.svg.renderer, self)
 
     def boundingRect(self):
         """
@@ -1208,9 +1186,9 @@ class QwtSymbol(object):
             pinPointTranslation = True
         elif self.__data.style == QwtSymbol.Pixmap:
             if self.__data.size.isEmpty():
-                rect.setSize(self.__data.pixmap.pixmap.size())
+                rect.setSize(QSizeF(self.pixmap().size()))
             else:
-                rect.setSize(self.__data.size)
+                rect.setSize(QSizeF(self.__data.size))
             pinPointTranslation = True
         elif self.__data.style == QwtSymbol.Graphic:
             rect = qwtScaleBoundingRect(self.__data.graphic.graphic, self.__data.size)
@@ -1227,7 +1205,7 @@ class QwtSymbol(object):
                 rect = transform.mapRect(rect)
             pinPointTranslation = True
         else:
-            rect.setSize(self.__data.size)
+            rect.setSize(QSizeF(self.__data.size))
             rect.moveCenter(QPointF(0.0, 0.0))
         if pinPointTranslation:
             pinPoint = QPointF(0.0, 0.0)
